@@ -23,7 +23,6 @@ httd = function(dir = '.', ...) {
     owd = setwd(dir); on.exit(setwd(owd))
   }
   res = server_config(dir, ...)
-  res$browse()
   app = list(call = serve_dir(dir))
   res$start_server(app)
 }
@@ -122,14 +121,27 @@ server_config = function(
   url = sprintf('http://%s:%d', host, port)
   if (baseurl != '') url = paste(url, baseurl, sep = '')
   url = paste0(url, if (initpath != '' && !grepl('^/', initpath)) '/', initpath)
+  browsed = FALSE
+  browse = function() {
+    if (browsed) return(invisible(url))
+    if (browser) {
+      browseURL(url, browser = get_browser())
+    }
+    browsed <<- TRUE
+    message('Serving the directory ', dir, ' at ', url)
+  }
   list(
     host = host, port = port, interval = interval, url = url,
     start_server = function(app) {
       # a built-in daemonized server
-      if (daemon && !requireNamespace('later', quietly = TRUE))
-        return(daemon_hint(startDaemonizedServer(host, port, app)))
+      if (daemon && !requireNamespace('later', quietly = TRUE)) {
+        id = startDaemonizedServer(host, port, app)
+        browse()
+        return(daemon_hint(id))
+      }
 
       server = startServer(host, port, app)
+      browse()
       # a daemonized server based on later
       if (daemon) {
         daemon_hint(server, TRUE)
@@ -147,12 +159,7 @@ server_config = function(
         }
       }
     },
-    browse = function() {
-      if (browser) {
-        browseURL(url, browser = get_browser())
-      }
-      message('Serving the directory ', dir, ' at ', url)
-    }
+    browse = browse
   )
 }
 
