@@ -1,4 +1,5 @@
 #' @import stats utils
+#' @importFrom xfun in_dir
 
 servrEnv = new.env(parent = emptyenv())
 
@@ -75,11 +76,6 @@ rscript = function(code, input) {
     stop('Failed to compile ', input, call. = FALSE)
 }
 
-in_dir = function(dir, expr) {
-  owd = setwd(dir); on.exit(setwd(owd))
-  expr
-}
-
 new_timeout = function(interval, max_timeout = 32) {
   old = NULL
   int = interval  # stores initial value (may need to restore later)
